@@ -152,6 +152,8 @@ static const char* acceptable_fields[] = {
     "IwlFwDump",
     /* System Image information from imaged systems */
     "SystemImageInfo",
+    /* We always want to know why apport thought it shouldn't be reported. */
+    "UnreportableReason",
 
     NULL,
 };
@@ -162,10 +164,6 @@ static const char* unacceptable_fields[] = {
     "Stacktrace",
     "ThreadStacktrace",
 
-    /* We would only want this to see how many bugs would otherwise go
-     * unreported: */
-    "UnreportableReason",
-
     /* We'll have our own count in the database. */
     "CrashCounter",
 
@@ -418,8 +416,8 @@ parse_report (const char* report_path, gboolean full_report, GError** error)
             memcpy (value_p, p, value_length);
             value_p[value_length] = '\0';
             for (char *c = value_p; c < value_p + value_length; c++)
-                /* If c is a control character. */
-                if (*c >= '\0' && *c < ' ')
+                /* If c is a control character but not TAB. */
+                if (*c != '\t' && *c >= '\0' && *c < ' ')
                     *c = '?';
             value_p += value_length;
             g_hash_table_insert (hash_table, key, value ? value : "");
